'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = log;
exports.hookConsoleLog = hookConsoleLog;
var consoleLog = console.log.bind(console);

var chromeRegex = new RegExp('^\\s*?at\\s*(\\S*?)\\s'); // at ExampleConsoleLog.hello (example.js:93)
var firefoxRegex = new RegExp('^\\s*(\\S*?)@\\S*\\/(\\S*)\\.'); // hello@file:///~~~~~~/stacklogger/distribution/example.js:78:9
function log() {
  var stackframe = new Error().stack.split('\n');
  // try to match chrome first
  var match = chromeRegex.exec(stackframe[2]);
  var callee = match ? match[1] : null;
  if (!callee) {
    // try firefox
    match = firefoxRegex.exec(stackframe[1]);
    callee = match ? match[2] + '.' + match[1] : '';
  }
  var className = callee.split('.')[0];
  // make a certain className always have the same background color by computing a hash on it
  var hash = getHashCode(className) % colors.length;
  consoleLog.apply(undefined, ['%c' + callee, 'color: #000; background: ' + colors[hash]].concat(Array.prototype.slice.call(arguments)));
}

var getHashCode = function getHashCode(s) {
  return s.split('').reduce(function (prevHash, curChar) {
    return prevHash * 31 + curChar.charCodeAt(0);
  }, 0);
};

function hookConsoleLog() {
  console.log = log;
}

// colors created by enumerating HSL color wheel from 0...360 in 30 degree steps, with luminosity 75 and 90
var colors = ['#ff8080', '#ffcccc', '#ffbf80', '#ffe6cc', '#ffff80', '#ffffcc', '#bfff80', '#e6ffcc', '#80ff80', '#ccffcc', '#80ffbf', '#ccffe6', '#80ffff', '#ccffff', '#80bfff', '#cce5ff', '#8080ff', '#ccccff', '#bf80ff', '#e5ccff', '#ff80ff', '#ffccff', '#ff80bf', '#ffcce6'];